@@ -1,7 +1,7 @@
 package Test::Synopsis;
 use strict;
 use 5.008_001;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use base qw( Exporter );
 our @EXPORT = qw( synopsis_ok all_synopsis_ok );
@@ -29,7 +29,8 @@ sub synopsis_ok {
         }
 
         my $option = join(";", @option);
-        if (eval "$option; sub { $code }") {
+        my $test   = "$option; sub { $code }";
+        if (_compile($test)) {
             $Test->ok(1, $module);
         } else {
             $Test->ok(0, $@);
@@ -37,6 +38,12 @@ sub synopsis_ok {
     }
 }
 
+sub _compile {
+    package
+        Test::Synopsis::Sandbox;
+    eval $_[0];
+}
+
 sub extract_synopsis {
     my $file = shift;
 
@@ -81,6 +88,9 @@ Test::Synopsis is an (author) test module to find .pm or .pod files
 under your I<lib> directory and then make sure the example snippet
 code in your I<SYNOPSIS> section passes the perl compile check.
 
+Note that this module only checks the perl syntax (by wrapping the
+code with C<sub>) and doesn't actually run the code.
+
 Suppose you have the following POD in your module.
 
   =head1 NAME
